Documentation
¶
Overview ¶
Package flow can be used to test MQTT packet flows.
Index ¶
- type Conn
- type Flow
- func (f *Flow) Close() *Flow
- func (f *Flow) Debug() *Flow
- func (f *Flow) End() *Flow
- func (f *Flow) Receive(pkts ...packet.Generic) *Flow
- func (f *Flow) Run(fn func()) *Flow
- func (f *Flow) Send(pkts ...packet.Generic) *Flow
- func (f *Flow) Skip(pkts ...packet.Generic) *Flow
- func (f *Flow) Test(conn Conn) error
- func (f *Flow) TestAsync(conn Conn, timeout time.Duration) <-chan error
- type Pipe
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Conn ¶
type Conn interface {
Send(pkt packet.Generic, async bool) error
Receive() (packet.Generic, error)
Close() error
}
A Conn defines an abstract interface for connections used with a Flow.
type Flow ¶
type Flow struct {
// contains filtered or unexported fields
}
A Flow is a sequence of actions that can be tested against a connection.
Click to show internal directories.
Click to hide internal directories.